@@ -38,20 +38,25 @@
 #define cButModeTopMargin DIP2PIXEL(1)
 #define cButModeBottomMargin DIP2PIXEL(2)
 
-struct _CButMode {
-  ::Block *Block;
-  CodeType Code[cButModeCount + 1];
-  int NCode;
-  int Mode[cButModeInputCount];
-  int NBut;
-  float Rate;
-  float RateShown;
-  float Samples, Delay;
-  float TextColor1[3];
-  float TextColor2[3];
-  float TextColor3[3];
-  int DeferCnt;
-  float DeferTime;
+struct CButMode : public Block {
+  CodeType Code[cButModeCount + 1] {};
+  int NCode {};
+  int Mode[cButModeInputCount] {};
+  int NBut {};
+  float Rate { 0.0f };
+  float RateShown { 0.0f };
+  float Samples { 0.0f }, Delay { 0.0f };
+  float TextColor1[3] = { 0.5f, 0.5f, 1.0f };
+  float TextColor2[3] = { 0.8f, 0.8f, 0.8f };
+  float TextColor3[3] = { 1.0f, 0.5f, 0.5f };
+  int DeferCnt { 0 };
+  float DeferTime { 0.0f };
+
+  CButMode(PyMOLGlobals * G) : Block(G) {}
+
+  int click(int button, int x, int y, int mod) override;
+  void draw(CGO *orthoCGO) override;
+  bool fastDraw(CGO* orthoCGO) override;
 };
 
 
@@ -60,7 +65,7 @@ Block *ButModeGetBlock(PyMOLGlobals * G)
 {
   CButMode *I = G->ButMode;
   {
-    return (I->Block);
+    return (I);
   }
 }
 
@@ -136,17 +141,14 @@ void ButModeResetRate(PyMOLGlobals * G)
 /*========================================================================*/
 void ButModeFree(PyMOLGlobals * G)
 {
-  CButMode *I = G->ButMode;
-  OrthoFreeBlock(G, I->Block);
-  FreeP(G->ButMode);
+  DeleteP(G->ButMode);
 }
 
 
 /*========================================================================*/
-static int ButModeClick(Block * block, int button, int x, int y, int mod)
+int CButMode::click(int button, int x, int y, int mod)
 {
-  PyMOLGlobals *G = block->G;
-  int dy = (y - block->rect.bottom) / cButModeLineHeight;
+  int dy = (y - rect.bottom) / cButModeLineHeight;
   //  int dx = (x - block->rect.left);
   int forward = 1; 
   // TAKEN OUT : BB 12/11 : Mouse position should not have
@@ -160,264 +162,262 @@ static int ButModeClick(Block * block, int button, int x, int y, int mod)
   if(mod == cOrthoSHIFT)
     forward = !forward;
   if(dy < 2) {
-    if(ButModeTranslate(G, P_GLUT_SINGLE_LEFT, 0) != cButModePickAtom) {
+    if(ButModeTranslate(m_G, P_GLUT_SINGLE_LEFT, 0) != cButModePickAtom) {
       if(!forward) {
-        PLog(G, "cmd.mouse('select_backward')", cPLog_pym);
-        OrthoCommandIn(G, "mouse select_backward,quiet=1");
+        PLog(m_G, "cmd.mouse('select_backward')", cPLog_pym);
+        OrthoCommandIn(m_G, "mouse select_backward,quiet=1");
       } else {
-        PLog(G, "cmd.mouse('select_forward')", cPLog_pym);
-        OrthoCommandIn(G, "mouse select_forward,quiet=1");
+        PLog(m_G, "cmd.mouse('select_forward')", cPLog_pym);
+        OrthoCommandIn(m_G, "mouse select_forward,quiet=1");
       }
     }
   } else {
     if(button == P_GLUT_RIGHT_BUTTON) {
-      MenuActivate0Arg(G,x,y,x,y,false,"mouse_config");
+      MenuActivate0Arg(m_G,x,y,x,y,false,"mouse_config");
     } else {
       if(!forward) {
-        PLog(G, "cmd.mouse('backward')", cPLog_pym);
-        OrthoCommandIn(G, "mouse backward,quiet=1");
+        PLog(m_G, "cmd.mouse('backward')", cPLog_pym);
+        OrthoCommandIn(m_G, "mouse backward,quiet=1");
       } else {
-        PLog(G, "cmd.mouse('forward')", cPLog_pym);
-        OrthoCommandIn(G, "mouse forward,quiet=1");
+        PLog(m_G, "cmd.mouse('forward')", cPLog_pym);
+        OrthoCommandIn(m_G, "mouse forward,quiet=1");
       }
     }
   }
   return (1);
 }
 
-short ButModeDrawFastImpl(Block * block, short definitely ORTHOCGOARG);
+static bool ButModeDrawFastImpl(Block * block, short definitely , CGO *orthoCGO);
 /*========================================================================*/
-static void ButModeDraw(Block * block ORTHOCGOARG)
+void CButMode::draw(CGO* orthoCGO)
 {
-  PyMOLGlobals *G = block->G;
-  CButMode *I = G->ButMode;
   int x, y, a;
   int mode;
-  float *textColor = I->Block->TextColor;
-  float *textColor2 = I->TextColor2;
-
+  const float *textColor = TextColor;
+  const float *textColor2 = TextColor2;
+  CButMode *I = this; // TODO: Remove during ButMode refactor
 #define BLANK_STR "     "
 
-  if(G->HaveGUI && G->ValidContext && ((block->rect.right - block->rect.left) > 6)) {
-    if(SettingGetGlobal_b(G, cSetting_internal_gui_mode) == 0) {
+  if(m_G->HaveGUI && m_G->ValidContext && ((rect.right - rect.left) > 6)) {
+    if(SettingGet<InternalGUIMode>(m_G, cSetting_internal_gui_mode) == InternalGUIMode::Default) {
       if (orthoCGO)
-	CGOColorv(orthoCGO, I->Block->BackColor);
+	CGOColorv(orthoCGO, BackColor);
 #ifndef PURE_OPENGL_ES_2
       else
-	glColor3fv(I->Block->BackColor);
+	glColor3fv(BackColor);
 #endif
-      BlockFill(I->Block ORTHOCGOARGVAR);
-      BlockDrawLeftEdge(I->Block ORTHOCGOARGVAR);
+      fill(orthoCGO);
+      drawLeftEdge(orthoCGO);
     } else {
-      BlockDrawLeftEdge(I->Block ORTHOCGOARGVAR);
+      drawLeftEdge(orthoCGO);
       if (orthoCGO)
 	CGOColor(orthoCGO, .5f, .5f, .5f);
 #ifndef PURE_OPENGL_ES_2
       else
 	glColor3f(0.5, 0.5, 0.5);
 #endif
-      BlockDrawTopEdge(I->Block);
-      textColor2 = OrthoGetOverlayColor(G);
+      drawTopEdge();
+      textColor2 = OrthoGetOverlayColor(m_G);
       textColor = textColor2;
     }
 
-    x = I->Block->rect.left + cButModeLeftMargin;
-    y = (I->Block->rect.top - cButModeLineHeight) - cButModeTopMargin;
+    x = rect.left + cButModeLeftMargin;
+    y = (rect.top - cButModeLineHeight) - cButModeTopMargin;
 
-    TextSetColor(G, textColor);
-    TextDrawStrAt(G, "Mouse Mode ", x + 1, y ORTHOCGOARGVAR);
-    TextSetColor(G, I->TextColor3);
-    TextDrawStrAt(G, SettingGetGlobal_s(G, cSetting_button_mode_name), x + DIP2PIXEL(88), y ORTHOCGOARGVAR);
-    /*    TextDrawStrAt(G,"2-Bttn Selecting",x+88,y); */
+    TextSetColor(m_G, textColor);
+    TextDrawStrAt(m_G, "Mouse Mode ", x + 1, y, orthoCGO);
+    TextSetColor(m_G, TextColor3);
+    TextDrawStrAt(m_G, SettingGetGlobal_s(m_G, cSetting_button_mode_name), x + DIP2PIXEL(88), y, orthoCGO);
+    /*    TextDrawStrAt(m_G,"2-Bttn Selecting",x+88,y); */
     y -= cButModeLineHeight;
 
-    if(SettingGetGlobal_b(G, cSetting_mouse_grid)) {
+    if(SettingGetGlobal_b(m_G, cSetting_mouse_grid)) {
 
-      TextSetColor(G, I->TextColor3);
-      TextDrawStrAt(G, "Buttons", x + DIP2PIXEL(6), y ORTHOCGOARGVAR);
-      TextSetColor(G, I->TextColor1);
-      /*    TextDrawStrAt(G,"  Left Mddl Rght Scrl",x+48,y); */
-      TextDrawStrAt(G, "    L    M    R  Wheel", x + DIP2PIXEL(43), y ORTHOCGOARGVAR);
+      TextSetColor(m_G, TextColor3);
+      TextDrawStrAt(m_G, "Buttons", x + DIP2PIXEL(6), y, orthoCGO);
+      TextSetColor(m_G, TextColor1);
+      /*    TextDrawStrAt(m_G,"  Left Mddl Rght Scrl",x+48,y); */
+      TextDrawStrAt(m_G, "    L    M    R  Wheel", x + DIP2PIXEL(43), y, orthoCGO);
 
       y -= cButModeLineHeight;
       /*    glColor3fv(I->Block->TextColor);
-         TextDrawStrAt(G,"K",x,y-4); */
-      TextSetColor(G, I->TextColor3);
-      TextDrawStrAt(G, "&", x + DIP2PIXEL(12), y ORTHOCGOARGVAR);
-      TextDrawStrAt(G, "Keys", x + DIP2PIXEL(24), y ORTHOCGOARGVAR);
-      TextSetColor(G, textColor2);
+         TextDrawStrAt(m_G,"K",x,y-4); */
+      TextSetColor(m_G, TextColor3);
+      TextDrawStrAt(m_G, "&", x + DIP2PIXEL(12), y, orthoCGO);
+      TextDrawStrAt(m_G, "Keys", x + DIP2PIXEL(24), y, orthoCGO);
+      TextSetColor(m_G, textColor2);
 
-      TextSetPos2i(G, x + DIP2PIXEL(64), y);
+      TextSetPos2i(m_G, x + DIP2PIXEL(64), y);
       for(a = 0; a < 3; a++) {
-        mode = I->Mode[a];
+        mode = Mode[a];
         if(mode < 0)
-          TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+          TextDrawStr(m_G, BLANK_STR, orthoCGO);
         else
-          TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+          TextDrawStr(m_G, Code[mode], orthoCGO);
       }
-      mode = I->Mode[12];
+      mode = Mode[12];
       if(mode < 0)
-        TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+        TextDrawStr(m_G, BLANK_STR, orthoCGO);
       else
-        TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+        TextDrawStr(m_G, Code[mode], orthoCGO);
 
       y -= cButModeLineHeight;
-      /*    TextSetColor(G,I->Block->TextColor);
-         TextDrawStrAt(G,"e",x+5,y-1); */
-      TextSetColor(G, I->TextColor1);
+      /*    TextSetColor(m_G,I->Block->TextColor);
+         TextDrawStrAt(m_G,"e",x+5,y-1); */
+      TextSetColor(m_G, TextColor1);
 
-      TextSetColor(G, I->TextColor1);
-      TextDrawStrAt(G, "Shft ", x + DIP2PIXEL(24), y ORTHOCGOARGVAR);
-      TextSetColor(G, textColor2);
-      TextSetPos2i(G, x + DIP2PIXEL(64), y);
+      TextSetColor(m_G, TextColor1);
+      TextDrawStrAt(m_G, "Shft ", x + DIP2PIXEL(24), y, orthoCGO);
+      TextSetColor(m_G, textColor2);
+      TextSetPos2i(m_G, x + DIP2PIXEL(64), y);
       for(a = 3; a < 6; a++) {
         mode = I->Mode[a];
         if(mode < 0)
-          TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+          TextDrawStr(m_G, BLANK_STR, orthoCGO);
         else
-          TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+          TextDrawStr(m_G, Code[mode], orthoCGO);
       }
-      mode = I->Mode[13];
+      mode = Mode[13];
       if(mode < 0)
-        TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+        TextDrawStr(m_G, BLANK_STR, orthoCGO);
       else
-        TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+        TextDrawStr(m_G, Code[mode], orthoCGO);
 
       y -= cButModeLineHeight;
       /*    glColor3fv(I->Block->TextColor);
-         TextDrawStrAt(G,"y",x+10,y+2); */
-      TextSetColor(G, I->TextColor1);
-      TextDrawStrAt(G, "Ctrl ", x + DIP2PIXEL(24), y ORTHOCGOARGVAR);
-      TextSetColor(G, textColor2);
-      TextSetPos2i(G, x + DIP2PIXEL(64), y);
+         TextDrawStrAt(m_G,"y",x+10,y+2); */
+      TextSetColor(m_G, TextColor1);
+      TextDrawStrAt(m_G, "Ctrl ", x + DIP2PIXEL(24), y, orthoCGO);
+      TextSetColor(m_G, textColor2);
+      TextSetPos2i(m_G, x + DIP2PIXEL(64), y);
       for(a = 6; a < 9; a++) {
         mode = I->Mode[a];
         if(mode < 0)
-          TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+          TextDrawStr(m_G, BLANK_STR, orthoCGO);
         else
-          TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+          TextDrawStr(m_G, Code[mode], orthoCGO);
       }
       mode = I->Mode[14];
       if(mode < 0)
-        TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+        TextDrawStr(m_G, BLANK_STR, orthoCGO);
       else
-        TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+        TextDrawStr(m_G, Code[mode], orthoCGO);
       y -= cButModeLineHeight;
 
       /*    glColor3fv(I->Block->TextColor);
-         TextDrawStrAt(G,"s",x+15,y+3); */
-      TextSetColor(G, I->TextColor1);
-      TextSetColor(G, I->TextColor1);
-      TextDrawStrAt(G, "CtSh ", x + DIP2PIXEL(24), y ORTHOCGOARGVAR);
-      TextSetColor(G, textColor2);
-      TextSetPos2i(G, x + DIP2PIXEL(64), y);
+         TextDrawStrAt(m_G,"s",x+15,y+3); */
+      TextSetColor(m_G, TextColor1);
+      TextSetColor(m_G, TextColor1);
+      TextDrawStrAt(m_G, "CtSh ", x + DIP2PIXEL(24), y, orthoCGO);
+      TextSetColor(m_G, textColor2);
+      TextSetPos2i(m_G, x + DIP2PIXEL(64), y);
       for(a = 9; a < 12; a++) {
-        mode = I->Mode[a];
+        mode = Mode[a];
         if(mode < 0)
-          TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+          TextDrawStr(m_G, BLANK_STR, orthoCGO);
         else
-          TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+          TextDrawStr(m_G, Code[mode], orthoCGO);
       }
-      mode = I->Mode[15];
+      mode = Mode[15];
       if(mode < 0)
-        TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+        TextDrawStr(m_G, BLANK_STR, orthoCGO);
       else
-        TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+        TextDrawStr(m_G, Code[mode], orthoCGO);
 
       y -= cButModeLineHeight;
 
-      TextSetColor(G, I->Block->TextColor);
-      TextSetColor(G, I->TextColor1);
-      TextDrawStrAt(G, " SnglClk", x - DIP2PIXEL(8), y ORTHOCGOARGVAR);
-      TextSetColor(G, textColor2);
-      TextSetPos2i(G, x + DIP2PIXEL(64), y);
+      TextSetColor(m_G, TextColor);
+      TextSetColor(m_G, TextColor1);
+      TextDrawStrAt(m_G, " SnglClk", x - DIP2PIXEL(8), y, orthoCGO);
+      TextSetColor(m_G, textColor2);
+      TextSetPos2i(m_G, x + DIP2PIXEL(64), y);
       for(a = 19; a < 22; a++) {
-        mode = I->Mode[a];
+        mode = Mode[a];
         if(mode < 0)
-          TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+          TextDrawStr(m_G, BLANK_STR, orthoCGO);
         else
-          TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+          TextDrawStr(m_G, Code[mode], orthoCGO);
       }
-      TextSetColor(G, I->Block->TextColor);
+      TextSetColor(m_G, TextColor);
       y -= cButModeLineHeight;
 
-      TextSetColor(G, I->Block->TextColor);
-      TextSetColor(G, I->TextColor1);
-      TextDrawStrAt(G, " DblClk", x, y ORTHOCGOARGVAR);
-      TextSetColor(G, textColor2);
-      TextSetPos2i(G, x + DIP2PIXEL(64), y);
+      TextSetColor(m_G, TextColor);
+      TextSetColor(m_G, TextColor1);
+      TextDrawStrAt(m_G, " DblClk", x, y, orthoCGO);
+      TextSetColor(m_G, textColor2);
+      TextSetPos2i(m_G, x + DIP2PIXEL(64), y);
       for(a = 16; a < 19; a++) {
         mode = I->Mode[a];
         if(mode < 0)
-          TextDrawStr(G, BLANK_STR ORTHOCGOARGVAR);
+          TextDrawStr(m_G, BLANK_STR, orthoCGO);
         else
-          TextDrawStr(G, I->Code[mode] ORTHOCGOARGVAR);
+          TextDrawStr(m_G, Code[mode], orthoCGO);
       }
-      TextSetColor(G, I->Block->TextColor);
+      TextSetColor(m_G, TextColor);
       y -= cButModeLineHeight;
 
     }
 
     {
-      TextSetColor(G, textColor);
-      if(ButModeTranslate(G, P_GLUT_SINGLE_LEFT, 0) == cButModePickAtom) {
-        TextDrawStrAt(G, "Picking ", x, y ORTHOCGOARGVAR);
-        TextSetColor(G, I->TextColor3);
-        TextDrawStrAt(G, "Atoms (and Joints)", x + DIP2PIXEL(64), y ORTHOCGOARGVAR);
+      TextSetColor(m_G, textColor);
+      if(ButModeTranslate(m_G, P_GLUT_SINGLE_LEFT, 0) == cButModePickAtom) {
+        TextDrawStrAt(m_G, "Picking ", x, y, orthoCGO);
+        TextSetColor(m_G, TextColor3);
+        TextDrawStrAt(m_G, "Atoms (and Joints)", x + DIP2PIXEL(64), y, orthoCGO);
       } else {
-        TextDrawStrAt(G, "Selecting ", x, y ORTHOCGOARGVAR);
-        TextSetColor(G, I->TextColor3);
-        switch (SettingGetGlobal_i(G, cSetting_mouse_selection_mode)) {
+        TextDrawStrAt(m_G, "Selecting ", x, y, orthoCGO);
+        TextSetColor(m_G, TextColor3);
+        switch (SettingGetGlobal_i(m_G, cSetting_mouse_selection_mode)) {
         case 0:
-          TextDrawStrAt(G, "Atoms", x + DIP2PIXEL(80), y ORTHOCGOARGVAR);
+          TextDrawStrAt(m_G, "Atoms", x + DIP2PIXEL(80), y, orthoCGO);
           break;
         case 1:
-          TextDrawStrAt(G, "Residues", x + DIP2PIXEL(80), y ORTHOCGOARGVAR);
+          TextDrawStrAt(m_G, "Residues", x + DIP2PIXEL(80), y, orthoCGO);
           break;
         case 2:
-          TextDrawStrAt(G, "Chains", x + DIP2PIXEL(80), y ORTHOCGOARGVAR);
+          TextDrawStrAt(m_G, "Chains", x + DIP2PIXEL(80), y, orthoCGO);
           break;
         case 3:
-          TextDrawStrAt(G, "Segments", x + DIP2PIXEL(80), y ORTHOCGOARGVAR);
+          TextDrawStrAt(m_G, "Segments", x + DIP2PIXEL(80), y, orthoCGO);
           break;
         case 4:
-          TextDrawStrAt(G, "Objects", x + DIP2PIXEL(80), y ORTHOCGOARGVAR);
+          TextDrawStrAt(m_G, "Objects", x + DIP2PIXEL(80), y, orthoCGO);
           break;
         case 5:
-          TextDrawStrAt(G, "Molecules", x + DIP2PIXEL(80), y ORTHOCGOARGVAR);
+          TextDrawStrAt(m_G, "Molecules", x + DIP2PIXEL(80), y, orthoCGO);
           break;
         case 6:
-          TextDrawStrAt(G, "C-alphas", x + DIP2PIXEL(80), y ORTHOCGOARGVAR);
+          TextDrawStrAt(m_G, "C-alphas", x + DIP2PIXEL(80), y, orthoCGO);
           break;
         }
       }
     }
   }
-  if (!ORTHOCGOARGB || !(SettingGetGlobal_b(G, cSetting_show_frame_rate) || MoviePlaying(G))) {
-    ButModeDrawFastImpl(block, true ORTHOCGOARGVAR);
+  if (!orthoCGO || !(SettingGetGlobal_b(m_G, cSetting_show_frame_rate) || MoviePlaying(m_G))) {
+    ButModeDrawFastImpl(this, true, orthoCGO);
   }
 }
 
-static short ButModeDrawFast(Block * block ORTHOCGOARG){
-  return ButModeDrawFastImpl(block, false ORTHOCGOARGVAR);
+bool CButMode::fastDraw(CGO* orthoCGO){
+  return ButModeDrawFastImpl(this, false, orthoCGO);
 }
 
-short ButModeDrawFastImpl(Block * block, short definitely ORTHOCGOARG)
+static bool ButModeDrawFastImpl(Block * block, short definitely , CGO *orthoCGO)
 {
-  PyMOLGlobals *G = block->G;
-  CButMode *I = G->ButMode;
+  PyMOLGlobals *G = block->m_G;
+  CButMode *I = block->m_G->ButMode;
   int x, y;
-  float *textColor = I->Block->TextColor;
+  float *textColor = I->TextColor;
   float *textColor2 = I->TextColor2;
 
   if (!definitely && (!(SettingGetGlobal_b(G, cSetting_show_frame_rate) || MoviePlaying(G)))) {
     return false;
   }
 
-  x = I->Block->rect.left + cButModeLeftMargin;
-  y = I->Block->rect.bottom + cButModeLineHeight + cButModeBottomMargin;
+  x = I->rect.left + cButModeLeftMargin;
+  y = I->rect.bottom + cButModeLineHeight + cButModeBottomMargin;
   
-  TextSetColor(G, I->Block->TextColor);
+  TextSetColor(G, I->TextColor);
   y -= cButModeLineHeight;
 #ifndef PURE_OPENGL_ES_2
     {
@@ -450,25 +450,25 @@ short ButModeDrawFastImpl(Block * block, short definitely ORTHOCGOARG)
       nf = 1;
     TextSetColor(G, textColor);
     if(has_movie) {
-      TextDrawStrAt(G, "Frame ", x, y ORTHOCGOARGVAR);
+      TextDrawStrAt(G, "Frame ", x, y, orthoCGO);
     } else {
-      TextDrawStrAt(G, "State ", x, y ORTHOCGOARGVAR);
+      TextDrawStrAt(G, "State ", x, y, orthoCGO);
     }
     TextSetColor(G, textColor2);
     sprintf(rateStr, "%4d/%4d ", SceneGetFrame(G) + 1, nf);
-    TextDrawStrAt(G, rateStr, x + DIP2PIXEL(48), y ORTHOCGOARGVAR);
+    TextDrawStrAt(G, rateStr, x + DIP2PIXEL(48), y, orthoCGO);
     if(frame_rate) {
       sprintf(rateStr,"%5.1f",I->RateShown);
-      TextDrawStrAt(G, rateStr, x + DIP2PIXEL(144), y ORTHOCGOARGVAR);
+      TextDrawStrAt(G, rateStr, x + DIP2PIXEL(144), y, orthoCGO);
       TextSetColor(G, textColor);
-      TextDrawStrAt(G, "Hz ", x + DIP2PIXEL(192), y ORTHOCGOARGVAR);
+      TextDrawStrAt(G, "Hz ", x + DIP2PIXEL(192), y, orthoCGO);
       TextSetColor(G, textColor2);
     } else if(has_movie) {
       TextSetColor(G, textColor);
-      TextDrawStrAt(G, "State ", x + DIP2PIXEL(128), y ORTHOCGOARGVAR);
+      TextDrawStrAt(G, "State ", x + DIP2PIXEL(128), y, orthoCGO);
       TextSetColor(G, textColor2);
       sprintf(rateStr," %4d",SceneGetState(G)+1);
-      TextDrawStrAt(G, rateStr, x + DIP2PIXEL(168), y ORTHOCGOARGVAR);
+      TextDrawStrAt(G, rateStr, x + DIP2PIXEL(168), y, orthoCGO);
     } else if(frame_rate) {
     }
   }
@@ -480,7 +480,7 @@ short ButModeDrawFastImpl(Block * block, short definitely ORTHOCGOARG)
 int ButModeInit(PyMOLGlobals * G)
 {
   CButMode *I = NULL;
-  if((I = (G->ButMode = Calloc(CButMode, 1)))) {
+  if((I = (G->ButMode = new CButMode(G)))) {
 
     int a;
 
@@ -554,16 +554,11 @@ int ButModeInit(PyMOLGlobals * G)
     strcpy(I->Code[cButModeMovL], "MovL " );
     strcpy(I->Code[cButModeMvzL], "MvzL " );
 
-    I->Block = OrthoNewBlock(G, NULL);
-    I->Block->fClick = ButModeClick;
-    I->Block->fDraw = ButModeDraw;
-    I->Block->fFastDraw = ButModeDrawFast;
-    I->Block->fReshape = BlockReshape;
-    I->Block->active = true;
+    I->active = true;
 
-    I->Block->TextColor[0] = 0.2F;
-    I->Block->TextColor[1] = 1.0F;
-    I->Block->TextColor[2] = 0.2F;
+    I->TextColor[0] = 0.2F;
+    I->TextColor[1] = 1.0F;
+    I->TextColor[2] = 0.2F;
 
     I->TextColor1[0] = 0.5F;
     I->TextColor1[1] = 0.5F;
@@ -577,7 +572,7 @@ int ButModeInit(PyMOLGlobals * G)
     I->TextColor3[1] = 0.5F;
     I->TextColor3[2] = 0.5F;
 
-    OrthoAttach(G, I->Block, cOrthoTool);
+    OrthoAttach(G, I, cOrthoTool);
     return 1;
   } else
     return 0;
